Optional Settings — django-frontend-skeleton 2.0.0 documentation

### Navigation

- index
- next |
- previous |
- django-frontend-skeleton 2.0.0 documentation »

# Optional Settings

There are a few optional settings for customization.

## DJFRONTEND_STATIC_URL

Set a dedicated static server or CDN for serving static files.

## DJFRONTEND_GA_SETDOMAINNAME

Set domain for multiple, or cross-domain tracking with Google Analytics.

## DJFRONTEND_GA_SETALLOWLINKER

To use _setAllowLinker method on target site for cross-domain tracking with Google Analytics. Set to ‘True’ to enable. Requires H5BP_GA_SETDOMAINNAME to be set.

### Navigation

- index
- next |
- previous |
- django-frontend-skeleton 2.0.0 documentation »